PasswordCredential class

Password Credential

Annotations

Constructors

PasswordCredential({required String? id, required String? password, String? name, String? iconUrl})
PasswordCredential.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
iconUrl → String?
final
id → String?
final
name → String?
final
password → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited